===========================
Glimix-core's documentation
===========================

:Date: |today|
:Version: |version|

Fast inference for Generalised Linear Mixed Models.

.. toctree::
    :caption: Table of contents
    :name: mastertoc
    :maxdepth: 4

    install
    mean
    cov
    lik
    link
    lmm
    glmm
    gp
    ggp
    random

*****************
Comments and bugs
*****************

You can get the source code and open issues `on Github.`_

.. _on Github.: https://github.com/limix/glimix-core

.. rubric:: References

.. [Min01] Minka, T. P. (2001, August). Expectation propagation for approximate
           Bayesian inference. In Proceedings of the Seventeenth conference on
           Uncertainty in artificial intelligence (pp. 362-369).
           Morgan Kaufmann Publishers Inc..
